@@ -52,10 +52,14 @@ public:
     Mixing
   };
 
-  //! \brief 󥹥ȥ饯
-  CEcaIAManager();
-  //! \brief ǥȥ饯
-  virtual ~CEcaIAManager();
+  //! \brief  Singleton󥹥󥹤롣
+  //! \return trueƤfalse֤
+  static bool createInstance();
+  //! \brief  Singleton󥹥󥹤˴롣
+  static void destroyInstance();
+  //! \brief  Singleton󥹥󥹤ؤΥݥ󥿤֤
+  //! \return ƤʤϡNULLݥ󥿤֤
+  static CEcaIAManager* instance();
 
   //! \brief  Ծ֤֤
   //! \return Ծ֡
@@ -177,6 +181,14 @@ public slots:
   void slotToggleBypass(const QString& strTrackName, bool bBypass);
 
 private:
+  //! Singleton󥹥󥹡
+  static CEcaIAManager* ecaIAManager;
+
+  //! \brief 󥹥ȥ饯
+  CEcaIAManager();
+  //! \brief ǥȥ饯
+  virtual ~CEcaIAManager();
+
   //! \brief ԡ󥹥ȥ饯ԡػߤ뤿ᡢprivate
   CEcaIAManager(const CEcaIAManager&);
   //! \brief 黻ҡػߤ뤿ᡢprivate
