@@ -90,3 +90,47 @@ CEcaTools::sampleFormat(const QString& strFileName)
 }
 
 /////////////////////////////////////////////////////////////////////////////
+
+int 
+CEcaTools::channelCount(const QString& strFileName)
+{
+  command("c-add Format");
+  command("ai-add " + DQ + strFileName + DQ);
+  command("ai-get-format");
+
+  QString strFormats = lastString();
+
+  command("ai-remove");
+  command("c-remove");
+
+  QStringList strlFormats = QStringList::split(",", strFormats);
+  if ( strlFormats.size() != 3 ) {
+    return 0;
+  }
+
+  return strlFormats[1].toInt();
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
+int
+CEcaTools::sampleRate(const QString& strFileName)
+{
+  command("c-add Format");
+  command("ai-add " + DQ + strFileName + DQ);
+  command("ai-get-format");
+
+  QString strFormats = lastString();
+
+  command("ai-remove");
+  command("c-remove");
+
+  QStringList strlFormats = QStringList::split(",", strFormats);
+  if ( strlFormats.size() != 3 ) {
+    return 0;
+  }
+
+  return strlFormats[2].toInt();
+}
+
+/////////////////////////////////////////////////////////////////////////////
