@@ -180,7 +180,15 @@ WVoxBase::addTrack(
           this, SIGNAL(stateChanged()));
 
   VLayoutTracks->addWidget(VoxTrackNew);
+  //! \todo refreshTrackOrderVectorϡvVoxTracksvTrackOrder֤
+  //! ƱƤɬפ롣
+  //! äơɤ餫Υ٥˥ȥååȤ
+  //! ɲä֤ǥ뤹ưʤ롣
+  //! ä߷פǤꡢȥå륷ƥ
+  //! ľɬפ롣
+  refreshTrackOrderVector();
   vVoxTracks.push_back(VoxTrackNew);
+  vTrackOrder.push_back(VoxTrackNew);
   VoxTrackNew->show();
 }
 
@@ -262,7 +270,9 @@ WVoxBase::addTracks(const QDomNode& nodTracks)
     VoxTrackNew->setMaxSessionLength(timeMaxSessionLength);
 
     VLayoutTracks->addWidget(VoxTrackNew);
+    refreshTrackOrderVector();
     vVoxTracks.push_back(VoxTrackNew);
+    vTrackOrder.push_back(VoxTrackNew);
     VoxTrackNew->show();
   }
 }
@@ -563,11 +573,12 @@ QDomNode
 WVoxBase::stateInDOM(QDomDocument* pDoc)
 {
   QDomElement eleTracks = pDoc->createElement("Tracks");
-  QValueVector<WVoxTrack*>::iterator it = vVoxTracks.begin();
-  while ( it != vVoxTracks.end() ) {
-    eleTracks.appendChild((*it)->stateInDOM(pDoc));
-    it++;
-  }
+
+  int nCount = vTrackOrder.size();
+  int i;
+  for ( i = 0; i < nCount; i++ ) {
+    eleTracks.appendChild(vTrackOrder[i]->stateInDOM(pDoc));
+  } 
 
   return eleTracks;
 }
@@ -587,8 +598,8 @@ WVoxBase::setMaxSessionLength(const QTime& time)
 
 /////////////////////////////////////////////////////////////////////////////
 
-CTrackInf
-WVoxBase::trackInfByDisplayOrder(int nID) const
+void 
+WVoxBase::refreshTrackOrderVector() const
 {
   // ¤ؤ줺˽ƥ뤵줿ϡ٥
   if ( vTrackOrder.size() == 0 ) {
@@ -598,7 +609,13 @@ WVoxBase::trackInfByDisplayOrder(int nID) const
       it++;
     }
   }
+}
 
+/////////////////////////////////////////////////////////////////////////////
+
+CTrackInf
+WVoxBase::trackInfByDisplayOrder(int nID) const
+{
   if ( nID < 0 || vTrackOrder.size() <= static_cast<uint>(nID) ) {
     return CTrackInf();
   }
@@ -779,14 +796,6 @@ WVoxBase::slotChangeTrackOrder(QValueVector<int> vOrder)
 
 /////////////////////////////////////////////////////////////////////////////
 
-void
-WVoxBase::slotAddTrack()
-{
-  addTrack("/dev/dsp", "/dev/dsp");
-}
-
-/////////////////////////////////////////////////////////////////////////////
-
 void
 WVoxBase::slotChangePosition(const QTime& time)
 {
