@@ -88,6 +88,7 @@ WVoxStorm::~WVoxStorm()
   delete ToggleActionInteractive;
 
   CLadspaFactory::destroyInstance();
+  CEcaIAManager::destroyInstance();
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -95,6 +96,8 @@ WVoxStorm::~WVoxStorm()
 void 
 WVoxStorm::initialize()
 {
+  CEcaIAManager::createInstance();
+  EcaIAManager = CEcaIAManager::instance();
   CLadspaFactory::createInstance(getenv("LADSPA_PATH"));
 
   setupActions();
@@ -135,15 +138,15 @@ WVoxStorm::initialize()
           this, SLOT(slotToggleBypass(const QString&, bool)));
 
   connect(VoxBase, SIGNAL(masterPositionChanged(const QTime&)),
-          &ecaIAManager, SLOT(slotSetMasterPosition(const QTime&)));
+          EcaIAManager, SLOT(slotSetMasterPosition(const QTime&)));
   connect(VoxBase, SIGNAL(stateChanged()), 
           this, SLOT(slotChangedState()));
-  connect(&ecaIAManager, SIGNAL(masterPositionChanged(const QTime&)),
+  connect(EcaIAManager, SIGNAL(masterPositionChanged(const QTime&)),
           VoxBase, SLOT(slotChangePosition(const QTime&)));
-  connect(&ecaIAManager, SIGNAL(finished()), this, SLOT(slotFinish()));
-  connect(&ecaIAManager, SIGNAL(messageGenerated(const QString&)),
+  connect(EcaIAManager, SIGNAL(finished()), this, SLOT(slotFinish()));
+  connect(EcaIAManager, SIGNAL(messageGenerated(const QString&)),
           VoxBase, SLOT(slotWriteConsoleMessage(const QString&)));
-  connect(&ecaIAManager, SIGNAL(moved(const QTime&)), 
+  connect(EcaIAManager, SIGNAL(moved(const QTime&)), 
           VoxBase, SLOT(slotNotifyCurrentTime(const QTime&)));
 
   pDocVox = NULL;
@@ -274,8 +277,8 @@ WVoxStorm::writeConfigurationFile()
 void 
 WVoxStorm::applyPreferences()
 {
-  ecaIAManager.setBufferSize(preferences.uiBuffer);
-  ecaIAManager.setSoundSourceFormat(preferences.format);
+  EcaIAManager->setBufferSize(preferences.uiBuffer);
+  EcaIAManager->setSoundSourceFormat(preferences.format);
   VoxBase->setMaxSessionLength(preferences.timeSessionMax);
 }
 
@@ -500,7 +503,7 @@ WVoxStorm::queryClose()
   if ( maybeSave() ) {
     QApplication::setOverrideCursor(waitCursor);
     if ( ToggleActionInteractive->isChecked() ) {
-      ecaIAManager.slotReleaseCurrentChainsetup();
+      EcaIAManager->slotReleaseCurrentChainsetup();
     }
     QApplication::restoreOverrideCursor();
 
@@ -657,10 +660,10 @@ void
 WVoxStorm::enterIAMode(bool bEnter)
 {
   if ( bEnter ) {
-    ecaIAManager.slotCreateNewChainsetup("VoxStorm");
+    EcaIAManager->slotCreateNewChainsetup("VoxStorm");
   } else {
     // clear chainsetup
-    ecaIAManager.slotReleaseCurrentChainsetup();
+    EcaIAManager->slotReleaseCurrentChainsetup();
   }
 }
 
@@ -679,11 +682,11 @@ WVoxStorm::setWidgetsByIAState()
 void 
 WVoxStorm::prepareChainsToManager()
 {
-  ecaIAManager.slotRemoveAllChains();
+  EcaIAManager->slotRemoveAllChains();
   int nCount = VoxBase->getTrackCount();
   int i;
   for ( i = 0; i < nCount; i++ ) {
-    ecaIAManager.slotAddChain(VoxBase->getTrackInf(i));
+    EcaIAManager->slotAddChain(VoxBase->getTrackInf(i));
   }
 }
 
@@ -843,14 +846,14 @@ WVoxStorm::slotPlay()
 
     // PAUSE -> PLAY
     if ( bPause ) {
-      ecaIAManager.slotResume();
+      EcaIAManager->slotResume();
       bPause = false;
     }
     // STOP -> PLAY
     else {
       prepareChainsToManager();
 
-      ecaIAManager.slotPlay(ToggleActionRec->isChecked());
+      EcaIAManager->slotPlay(ToggleActionRec->isChecked());
     }
   }
   QApplication::restoreOverrideCursor();
@@ -873,7 +876,7 @@ WVoxStorm::slotPause()
   LabelStatusBar->setText(i18n("Pausing..."));
   if ( ToggleActionInteractive->isChecked() ) {
     // STOP -> PAUSE
-    if ( ecaIAManager.runningStatus() == CEcaIAManager::NotRunning ) {
+    if ( EcaIAManager->runningStatus() == CEcaIAManager::NotRunning ) {
       prepareChainsToManager();
 
       ToggleActionRec->setEnabled(false);
@@ -885,9 +888,9 @@ WVoxStorm::slotPause()
     ActionPause->setEnabled(false);
     ActionPlay->setEnabled(true);
     VoxBase->slotChangeState(WVoxBase::Pause);
-    ecaIAManager.slotPause(ToggleActionRec->isChecked());
+    EcaIAManager->slotPause(ToggleActionRec->isChecked());
 
-    if ( ecaIAManager.runningStatus() == CEcaIAManager::Playing ) {
+    if ( EcaIAManager->runningStatus() == CEcaIAManager::Playing ) {
       bPause = true;
     }
   }
@@ -901,7 +904,7 @@ WVoxStorm::slotStop()
 {
   QApplication::setOverrideCursor(waitCursor);
   if ( ToggleActionInteractive->isChecked() ) {
-    ecaIAManager.slotStop();
+    EcaIAManager->slotStop();
   }
   QApplication::restoreOverrideCursor();
 }
@@ -913,7 +916,7 @@ WVoxStorm::slotJumpToStart()
 {
   QApplication::setOverrideCursor(waitCursor);
   if ( ToggleActionInteractive->isChecked() ) {
-    ecaIAManager.slotSetMasterPosition(0);
+    EcaIAManager->slotSetMasterPosition(0);
   }
   QApplication::restoreOverrideCursor();
 }
@@ -925,7 +928,7 @@ WVoxStorm::slotRewind()
 {
   QApplication::setOverrideCursor(waitCursor);
   if ( ToggleActionInteractive->isChecked() ) {    
-    ecaIAManager.slotRewind(preferences.iFrameSeconds);
+    EcaIAManager->slotRewind(preferences.iFrameSeconds);
   }
   QApplication::restoreOverrideCursor();
 }
@@ -937,7 +940,7 @@ WVoxStorm::slotForward()
 {
   QApplication::setOverrideCursor(waitCursor);
   if ( ToggleActionInteractive->isChecked() ) {
-    ecaIAManager.slotForward(preferences.iFrameSeconds);
+    EcaIAManager->slotForward(preferences.iFrameSeconds);
   }
   QApplication::restoreOverrideCursor();
 }
@@ -965,11 +968,11 @@ WVoxStorm::slotMixdown()
 
   LabelStatusBar->setText(i18n("Mixing..."));
 
-  ecaIAManager.slotRemoveAllChains();
+  EcaIAManager->slotRemoveAllChains();
   int nCount = VoxBase->getTrackCount();
   int i;
   for ( i = 0; i < nCount; i++ ) {
-    ecaIAManager.slotAddChain(VoxBase->getTrackInf(i));
+    EcaIAManager->slotAddChain(VoxBase->getTrackInf(i));
   }
 
   ActionPlay->setEnabled(false);
@@ -981,7 +984,7 @@ WVoxStorm::slotMixdown()
   ActionMixdown->setEnabled(false);
   VoxBase->slotChangeState(WVoxBase::Play);
   VoxBase->slotChangeMessageTab(WVoxBase::Console);
-  ecaIAManager.slotMixdown(
+  EcaIAManager->slotMixdown(
         mixdownDialog.mixesWithPlaying(), 
         "Mixdown", 
         mixdownDialog.fileName());
@@ -1073,7 +1076,7 @@ WVoxStorm::slotChangePlaybackDevice(const QString& strTrackName,
     // the track that has name as strTrackName is surely existing
     // so we not check existence of the track
 
-    ecaIAManager.slotChangePlaybackDevice(strTrackName, strPlaybackDevice);
+    EcaIAManager->slotChangePlaybackDevice(strTrackName, strPlaybackDevice);
   }
 }
 
@@ -1088,7 +1091,7 @@ WVoxStorm::slotChangeRecordingDevice(const QString& strTrackName,
     // the track that has name as strTrackName is surely existing
     // so we not check existence of the track
 
-    ecaIAManager.slotChangeRecordingDevice(strTrackName, strRecordingDevice);
+    EcaIAManager->slotChangeRecordingDevice(strTrackName, strRecordingDevice);
   }
 }
 
@@ -1098,7 +1101,7 @@ void
 WVoxStorm::slotRemoveTrack(const QString& strTrackName)
 {
   if ( ToggleActionInteractive->isChecked() ) {
-    ecaIAManager.slotRemoveChain(strTrackName);
+    EcaIAManager->slotRemoveChain(strTrackName);
   }
 }
 
@@ -1108,7 +1111,7 @@ void
 WVoxStorm::slotChangeFileName(const QString& strTrackName, const QString&)
 {
   if ( ToggleActionInteractive->isChecked() ) {
-    if ( !ecaIAManager.isExisting(strTrackName) ) {
+    if ( !EcaIAManager->isExisting(strTrackName) ) {
       ;
     } else {
       ;
@@ -1126,7 +1129,7 @@ WVoxStorm::slotChangeLevel(const QString& strTrackName, int nLevel)
     // the track that has name as strTrackName is surely existing
     // so we not check existence of the track
 
-    ecaIAManager.slotChangeLevel(strTrackName, nLevel);
+    EcaIAManager->slotChangeLevel(strTrackName, nLevel);
   }
 }
 
@@ -1140,7 +1143,7 @@ WVoxStorm::slotChangePan(const QString& strTrackName, int nPan)
     // the track that has name as strTrackName is surely existing
     // so we not check existence of the track
 
-    ecaIAManager.slotChangePan(strTrackName, nPan);
+    EcaIAManager->slotChangePan(strTrackName, nPan);
   }
 }
 
@@ -1154,7 +1157,7 @@ WVoxStorm::slotToggleMute(const QString& strTrackName, bool bMute)
     // the track that has name as strTrackName is surely existing
     // so we not check existence of the track
 
-    ecaIAManager.slotToggleMute(strTrackName, bMute);
+    EcaIAManager->slotToggleMute(strTrackName, bMute);
   }
 }
 
@@ -1168,7 +1171,7 @@ WVoxStorm::slotToggleRec(const QString& strTrackName, bool bRec)
     // the track that has name as strTrackName is surely existing
     // so we not check existence of the track
 
-    ecaIAManager.slotToggleRec(strTrackName, bRec);
+    EcaIAManager->slotToggleRec(strTrackName, bRec);
   }
 }
 
@@ -1184,7 +1187,7 @@ WVoxStorm::slotChangeStartPosition(
     // the track that has name as strTrackName is surely existing
     // so we not check existence of the track
 
-    ecaIAManager.slotChangeStartPosition(strTrackName, TimeStartPosition);
+    EcaIAManager->slotChangeStartPosition(strTrackName, TimeStartPosition);
   }
 }
 
@@ -1200,7 +1203,7 @@ WVoxStorm::slotChangeOffset(
     // the track that has name as strTrackName is surely existing
     // so we not check existence of the track
 
-    ecaIAManager.slotChangeOffset(strTrackName, TimeOffset);
+    EcaIAManager->slotChangeOffset(strTrackName, TimeOffset);
   }
 }
 
@@ -1216,7 +1219,7 @@ WVoxStorm::slotChangeLength(
     // the track that has name as strTrackName is surely existing
     // so we not check existence of the track
 
-    ecaIAManager.slotChangeLength(strTrackName, TimeLength);
+    EcaIAManager->slotChangeLength(strTrackName, TimeLength);
   }
 }
 
@@ -1232,7 +1235,7 @@ WVoxStorm::slotChangeEffects(
     // the track that has name as strTrackName is surely existing
     // so we not check existence of the track
 
-    ecaIAManager.slotChangeEffects(strTrackName, effects);
+    EcaIAManager->slotChangeEffects(strTrackName, effects);
   }
 }
 
@@ -1246,7 +1249,7 @@ WVoxStorm::slotToggleBypass(const QString& strTrackName, bool bBypass)
     // the track that has name as strTrackName is surely existing
     // so we not check existence of the track
 
-    ecaIAManager.slotToggleBypass(strTrackName, bBypass);
+    EcaIAManager->slotToggleBypass(strTrackName, bBypass);
   }
 }
 
